@@ -3,7 +3,7 @@ use serde::{Deserialize, Serialize};
 use serde_json::Value;
 use std::collections::{BTreeMap, HashMap};
 use std::io::{self, BufRead};
-use yansi::Paint;
+use yansi::{Color, Paint, Style}; // 0.6.5
 
 #[derive(Serialize, Deserialize, Debug)]
 struct Pac {
@@ -96,6 +96,8 @@ pub fn read_from_stdin(matches: &clap::ArgMatches) {
     let stdin = io::stdin();
     // check if filter-levels is specified
     let mut filter_levels = Vec::new();
+    let mut regexp_colours = HashMap::new();
+
     if matches.is_present("filter-levels") {
         filter_levels = matches
             .value_of("filter-levels")
@@ -104,7 +106,20 @@ pub fn read_from_stdin(matches: &clap::ArgMatches) {
             .map(|s| s.to_string())
             .collect();
     }
-
+    if matches.occurrences_of("regexp") > 0 {
+        let colours = vec![
+            Color::Yellow,
+            Color::Magenta,
+            Color::Cyan,
+            Color::Red,
+            Color::Blue,
+        ];
+        let regexps: Vec<&str> = matches.values_of("regexp").unwrap().collect();
+        // assign a colour to each regexp
+        for (i, regexp) in regexps.iter().enumerate() {
+            regexp_colours.insert(regexp.to_string(), colours[i % colours.len()]);
+        }
+    }
     for line in stdin.lock().lines() {
         let parseline = &line.unwrap();
         // exclude lines with only space or empty
@@ -139,12 +154,17 @@ pub fn read_from_stdin(matches: &clap::ArgMatches) {
                 "".to_string()
             };
             let mut themsg = msg.get("msg").unwrap().to_string();
-            if let Some(regexp) = matches.value_of("regexp") {
-                let re = Regex::new(format!(r"(?P<r>{})", regexp).as_str()).unwrap();
-                let _result = re
-                    .replace_all(&themsg, Paint::yellow("$r").to_string())
-                    .to_string();
-                themsg = _result;
+
+            if matches.occurrences_of("regexp") > 0 {
+                let regexps: Vec<&str> = matches.values_of("regexp").unwrap().collect();
+                for r in regexps {
+                    let re = Regex::new(format!(r"(?P<r>{})", r).as_str()).unwrap();
+                    let style = Style::new(regexp_colours[r]);
+                    let _result = re
+                        .replace_all(&themsg, style.paint("$r").to_string())
+                        .to_string();
+                    themsg = _result;
+                }
             }
 
             println!("{} {} {}{}", Paint::wrapping(level), ts, other, themsg);
